# -*- coding: utf-8 -*-

import sys

from typing import List

from PyQt5.QtCore import QCoreApplication

from libastra_csp.certificate import Certificate
from libastra_csp.common_settings import CommonSettings
from libastra_csp.common_functions import parse_certificates
from libastra_csp.common_functions import check_result

from astra_csp_cryptopro.common_functions import tuned_merge_certificate_process, tuned_certificates_process, \
    validate_cryptopro_config

translate = QCoreApplication.translate


def merge_certificates() -> None:
    validate_cryptopro_config()
    merge_certificates_process = tuned_merge_certificate_process()
    merge_certificates_process.add_silent_mode()
    merge_certificates_process.start()
    merge_certificates_process.waitForFinished(-1)
    try:
        check_result(merge_certificates_process)
    except Exception as exception:
        raise Exception(translate('text', 'Failed to add user certificates to certificate store.'), *exception.args)


def get_certificates_list() -> List[Certificate]:
    validate_cryptopro_config()
    settings = CommonSettings()
    settings.load()
    get_certificates_process = tuned_certificates_process()
    get_certificates_process.start()
    get_certificates_process.waitForFinished(settings.max_csp_time_waiting)
    try:
        check_result(get_certificates_process)
        if get_certificates_process.empty_list_error_occurred():
            raise Exception(translate('text', 'Certificates not available. Empty certificate list.'))
    except Exception as exception:
        raise Exception(translate('text', 'Failed to load certificates.'), *exception.args)
    else:
        return get_certificates_process.get_certificates()


def print_certificates_list() -> None:
    certificates = parse_certificates(get_certificates_list())
    for names in certificates.values():
        print(names, file=sys.stdout)
