# -*- coding: utf-8 -*-

from re import sub, search
from typing import Optional

from PyQt5.QtCore import QDir
from PyQt5.QtWidgets import QApplication

from libastra_csp.process import Process
from libastra_csp.utils import Utils
from astra_csp_cryptopro.cryptopro_settings import cryptopro_settings


translate = QApplication.translate


class CprocspProcess(Process):
    def __init__(self, bin_dir: QDir) -> None:
        self.__bin_dir = bin_dir
        super().__init__()

    @property
    def bin_dir(self) -> QDir:
        return self.__bin_dir

    def set_bin_name(self, bin_name: str) -> None:
        self.setProgram(self.__bin_dir.filePath(bin_name))

    def output_error_code(self) -> Optional[str]:
        output = Utils.to_utf8(self.standard_output_buffer)
        match = search(cryptopro_settings.dictionary['output_error_code_regexp'], output)
        if match:
            return match.group('code')
        else:
            return None

    def failed_output_error_code_occurred(self) -> bool:
        code = self.output_error_code()
        return code is not None and code != cryptopro_settings.dictionary['failed_output_error_code']

    def timestamp_error_occurred(self) -> bool:
        return self.output_error_code() == cryptopro_settings.dictionary['timestamp_error']

    def output(self) -> str:
        text = super().output()
        for pattern, replace in cryptopro_settings.dictionary.get('sub_process_output', {}).items():
            text = sub(pattern, replace, text)

        return text
