# -*- coding: utf-8 -*-

from PyQt5.QtCore import QDir

from astra_csp_cryptopro.cprocsp_process import CprocspProcess
from astra_csp_cryptopro.cryptopro_settings import cryptopro_settings


class CreateFileSignatureProcess(CprocspProcess):
    def __init__(self, bin_dir: QDir) -> None:
        super().__init__(bin_dir=bin_dir)
        self.__document = ''
        self.__signature = ''
        self.__setup()

    @property
    def document(self) -> str:
        return self.__document

    @property
    def signature(self) -> str:
        return self.__signature

    def __setup(self) -> None:
        self.set_bin_name(cryptopro_settings.dictionary['create_file_signature_bin_name'])

    def setup_arguments(self, file_path: str, sig_name: str, fingerprint: str, password: str = None, cli: bool = False,
                        der_format: bool = False, time_address: str = None) -> None:
        arguments = cryptopro_settings.dictionary.get('create_file_signature_first_arguments', []) + [fingerprint]
        if cli:
            arguments.append(cryptopro_settings.dictionary.get('silent_mode_argument', ''))
            arguments.append(cryptopro_settings.dictionary.get('throw_chain_errors_argument', ''))
            arguments += [cryptopro_settings.dictionary.get('create_file_signature_emplace_password_argument', ''),
                          password or '']

        if der_format:
            arguments += cryptopro_settings.dictionary.get('create_file_signature_der_format_arguments', [])
        if time_address:
            arguments += cryptopro_settings.dictionary.get('create_file_signature_time_address_arguments', []) + [time_address]
        arguments += cryptopro_settings.dictionary.get('create_file_signature_last_arguments', []) + [file_path, sig_name]
        self.setArguments(arguments)
        self.__document = file_path
        self.__signature = sig_name
