# -*- coding: utf-8 -*-

from typing import Optional, List, Dict

from libastra_csp.yaml_settings import YamlSettings


class CryptoproSettings(YamlSettings):
    __bin_paths_key = 'bin_paths'
    __time_address_key = 'time_address'

    def __init__(self) -> None:
        super().__init__(file_path='/usr/share/astra-csp/astra-csp-cryptopro.yaml')

    @property
    def bin_paths(self) -> Optional[Dict[str, List[str]]]:
        return self.dictionary.get(self.__bin_paths_key)

    @bin_paths.setter
    def bin_paths(self, paths: Dict[str, List[str]]) -> None:
        self.dictionary[self.__bin_paths_key] = paths

    @property
    def time_address(self) -> Optional[str]:
        return self.dictionary.get(self.__time_address_key)

    @time_address.setter
    def time_address(self, value: str) -> None:
        self.dictionary[self.__time_address_key] = value

    @property
    def time_mark_plugins(self) -> Optional[List[List[str]]]:
        return self.dictionary.get('time_mark_plugins')

    def validate(self) -> None:
        super().validate()
        self._check_parameter(self.__time_address_key, self.time_address)


cryptopro_settings = CryptoproSettings()
cryptopro_settings.load()
