#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import sys

import astra_csp_plugins

from typing import List
from argparse import ArgumentParser

from PyQt5.QtCore import QCoreApplication

from libastra_csp.plugins.plugin_loader import PluginLoader
from libastra_csp.plugins.csp_plugin import CspPlugin
from astra_csp_cryptopro.cryptopro_main import CryptoPro


def main() -> None:
    try:
        app = QCoreApplication(sys.argv)

        plugins = PluginLoader.load(module=astra_csp_plugins, plugin_type=CspPlugin)  # type: List[CspPlugin]
        for plugin in plugins:
            plugin.load()

        CryptoPro.load()

        parser = ArgumentParser()
        base_group = CryptoPro.create_parser_base_group(parser)
        for plugin in plugins:
            plugin.setup_parser_base_group(base_group)

        CryptoPro.setup_parser(parser)
        for plugin in plugins:
            plugin.setup_parser(parser)

        args = parser.parse_args()
        CryptoPro.exec(app, args)
        for plugin in plugins:
            plugin.exec(app, args)

        sys.exit(0)
    except Exception as exception:
        print(*exception.args, file=sys.stderr)
        sys.exit(1)


if __name__ == '__main__':
    main()
