# -*- coding: utf-8 -*-

from PyQt5.QtCore import QDir

from astra_csp_cryptopro.cprocsp_process import CprocspProcess
from astra_csp_cryptopro.cryptopro_settings import cryptopro_settings


class VerifyFileProcess(CprocspProcess):
    def __init__(self, bin_dir: QDir) -> None:
        super().__init__(bin_dir=bin_dir)
        self.__setup()

    def setup_arguments(self, file_path: str, check_timestamp: bool = False, sig_path: str = None,
                        cli: bool = None) -> None:
        arguments = cryptopro_settings.dictionary.get('verify_file_first_arguments', []).copy()
        if cli:
            arguments.append(cryptopro_settings.dictionary.get('silent_mode_argument', ''))
            arguments.append(cryptopro_settings.dictionary.get('throw_chain_errors_argument', ''))
        if sig_path:
            arguments += cryptopro_settings.dictionary.get('verify_file_sig_path_arguments', [])
            if check_timestamp:
                arguments += cryptopro_settings.dictionary.get('verify_file_check_timestamp_arguments', [])
            arguments += [file_path, sig_path]
        else:
            if check_timestamp:
                arguments += cryptopro_settings.dictionary.get('verify_file_check_timestamp_arguments', [])
            arguments.append(file_path)

        self.setArguments(arguments)

    def __setup(self) -> None:
        self.set_bin_name(cryptopro_settings.dictionary['verify_file_bin_name'])
